@@ -11,14 +11,24 @@ sub hello_world {
     "Hello World!";
 }
 
+sub foo {
+    "Foo!";
+}
+
 sub routes {
-    return [ [ 'get' => '/' => 'hello_world' ] ];
+    return [
+        [ 'get' => '/'    => 'hello_world' ],
+        [ 'get' => '/foo' => 'foo' ],
+
+        # Or, pass inline subs
+        [ 'get' => '/inline' => sub { 'Inline!!!' } ]
+    ];
 }
 
 1;
 
 use Dancer2;
-use Dancer2::Controllers qw(controllers);
+use Dancer2::Controllers;
 
 set port => 8080;
 
